# SFB 1280 MetaDataApp

## Introduction and wiki
One of the most important steps in managing research data is the creation of metadata. Metadata represents characteristics of the raw data collected, such as the creator, date, subjects. License, publisher, etc. are also metadata. However, selecting the appropriate metadata fields is a difficult task.  The easiest way is to have a template that contains a [mapping to bibliometric metadata standards](https://gitlab.ruhr-uni-bochum.de/sfb1280/metaapp_2/-/wikis/MetaDataApp-Wiki/Mapping-to-DublinCore-and-DataCite)) such as DublinCore and DataCite: The [SFB 1280 metadata schema](https://gitlab.ruhr-uni-bochum.de/sfb1280/metaapp_2/-/wikis/MetaDataApp-Wiki/SFB-1280-metadata-fields) is such a template with 16 fields developed by SFB representatives. In accordance with the [SFB's research data management policy](https://sfb1280.ruhr-uni-bochum.de/wp-content/uploads/2022/10/SFB1280_ResearchDataManagementPolicy_ADOPTED_20220928.pdf), storage of this metadata is mandatory for all SFB 1280 groups. 

Please refer to this project's [wiki page for information about the SFB 1280 metadata schema](https://gitlab.ruhr-uni-bochum.de/sfb1280/metaapp_2/-/wikis/home).


## About this project
To save researchers noticeable routine work in creating metadata in the medium term, the SFB 1280 INF project developed the SFB 1280 Metadata App. The MetaDataApp is a Java application that allows researchers to easily store metadata as local json files along with research data using an inheritance strategy.  It allows the input of SFB 1280 metadata, as well as the mandatory DublinCore and DataCite metadata that have no mapping to SFB 1280 metadata.

![](/images/ScreenshotMetaDataApp.png)

The MetaDataApp will store the entries in a json file format that allows further use in a database (see related project: [SFB 1280 DatabaseApp](https://gitlab.ruhr-uni-bochum.de/sfb1280/databaseapp)) and other repositories. Json is a well-established data-interchange format that can be transformed easily in any pipeline regardless of programming language use. The [SFB 1280 DatabaseApp](https://gitlab.ruhr-uni-bochum.de/sfb1280/databaseapp) is a additional developed Java application that makes the thus created metadata searable and search results esily retrievable.


## Structure of the project

#### Important Files and Folders
- **Source code**: The code of the actual project. Found in src/AppJ_V03.java
- **Libaries**: The crucial libaries are
    - gson.2.6.2.jar
    - jcalendar-1.4.jar
    - jgoodies-forms-1.8.0.jar
    - jgoodies-forms-1.8.0-source.jar
    - json-simple-1.1.jar
    - miglayout15-swing.jar
- **.classpath**: Might be importatant to setup the libs, but this can be done manual aswell.    


## Structure of the code

#### Line 0 to 71:
Imports.
External Libaries:
- JSON-Simpel
- GSON

Both for JSON handling

#### Line 92 to 266
Functions for inputfield formatting.
Those functions get a input component as a parameter and add certain listener to it. For example: This could be a listener, which colors the field red, whenever the input format is not correct.

#### Line 271 to 357
Utilily functions

#### Line 358 to 370
Java main function

#### Line 371 to 470
All used variable, which can be changed and will be saved are declared and initiated here.

#### Line 476 to 584
If there is already a meta.JSON file, then this code area will read the data out of this file into the variables.

#### Line 590 to 1640
UI of the application

#### Line 1641 to 1808
Adding special features to the UI. Such as adding enforced formats to inputfields.

#### Line 1809 to 1948
Save the content to a new meta.JSON file.

#### Line 1949 - END
UI (Panels)


## License and Citation
This work is licensed under a Creative Commons Attribution-ShareAlike 4.0 International License: https://creativecommons.org/licenses/by-sa/4.0/

Please cite as: Diers, Erik, Zomorodpoosh, Setareh, Linn, Sandra, Pacharra, Marlene, & Otto, Tobias. (2023). MetaDataApp...

## Contact
If you have any questions about the MetaDataApp, or if you have feature requests or found bugs, please contact the SFB's INF project via email: sfb1280data@rub.de

## Funding
The development of the SFB 1280 subject code generator was carried out as part of the SFB 1280 INF project, supported by the Deutsche Forschungsgemeinschaft DFG (German Research Foundation, project number (316803389)).

